@@ -58,15 +58,28 @@ if ( $dq_usage_text_shown == 0 ) {
 }
 echo '<object classid="clsid:D27CDB6E-AE6D-11cf-96B8-444553540000"
  codebase="http://download.macromedia.com/pub/shockwave/cabs/flash/swflash.cab#version=6,0,29,0"
- width="' . $dq_bar_width . '" height="' . $dq_bar_height . '">
- <param name="movie" value="' . $dq_sm_server . '/plugins/disk_quota/swf/quotaBar.swf">
- <param name=FlashVars value="' .
-"dq_details_text=$dq_details_text&dq_sm_server=$dq_sm_server
-&dq_fsname=$dq_fsname&dq_blocks=$dq_blocks&dq_quota=$dq_quota&dq_limit=$dq_limit&dq_grace=$dq_grace" .
-'"><param name="quality" value="high">
- <embed src="' . $dq_sm_server . '/plugins/disk_quota/swf/quotaBar.swf" FlashVars="' .
-"dq_details_text=$dq_details_text&dq_sm_server=$dq_sm_server
-&dq_fsname=$dq_fsname&dq_blocks=$dq_blocks&dq_quota=$dq_quota&dq_limit=$dq_limit&dq_grace=$dq_grace" .
+ width="' . $dq_bar_width . '" height="' . $dq_bar_height . '">';
+
+if ( $dq_show_details == 1 ) {
+    echo '<param name="movie" value="' . $dq_sm_server . '/plugins/disk_quota/swf/quotaBar.swf">';
+}
+elseif ( $dq_show_details == 0 ) {
+    echo '<param name="movie" value="' . $dq_sm_server . '/plugins/disk_quota/swf/quotaBar_no_det.swf">';
+}
+
+echo ' <param name=FlashVars value="' .
+"dq_details_text=$dq_details_text&dq_sm_server=$dq_sm_server&dq_fsname=$dq_fsname&dq_blocks=$dq_blocks&dq_quota=$dq_quota&dq_limit=$dq_limit&dq_grace=$dq_grace" .
+'"><param name="quality" value="high">';
+
+if ( $dq_show_details == 1 ) {
+   echo '<embed src="' . $dq_sm_server . '/plugins/disk_quota/swf/quotaBar.swf"';
+}
+elseif ( $dq_show_details == 0 ) {
+   echo '<embed src="' . $dq_sm_server . '/plugins/disk_quota/swf/quotaBar_no_det.swf"';
+}
+
+echo ' FlashVars="' .
+"dq_details_text=$dq_details_text&dq_sm_server=$dq_sm_server&dq_fsname=$dq_fsname&dq_blocks=$dq_blocks&dq_quota=$dq_quota&dq_limit=$dq_limit&dq_grace=$dq_grace" .
 '" quality="high" pluginspage="http://www.macromedia.com/go/getflashplayer"
  type="application/x-shockwave-flash"
  width="' . $dq_bar_width . '" height="' . $dq_bar_height . '"></embed>
@@ -74,10 +87,10 @@ echo '<object classid="clsid:D27CDB6E-AE6D-11cf-96B8-444553540000"
 <br>';
         }
     }
-    if ( $dq_click == 1 ) {
+    if ( $dq_click == 1 && $dq_show_details == 1 ) {
             echo $dq_click_text;
     }
-    elseif ( $dq_click > 1 ) {
+    elseif ( $dq_click > 1 && $dq_show_details == 1 ) {
             echo $dq_click_text_multi;
     }
     echo '</div>';
